@@ -20,8 +20,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -45,7 +45,9 @@ class InstanceIdTarget(
     """
 
     def __init__(
-        self, instance_id: str, port: typing.Optional[jsii.Number] = None
+        self,
+        instance_id: builtins.str,
+        port: typing.Optional[jsii.Number] = None,
     ) -> None:
         """Create a new Instance target.
 
@@ -59,7 +61,8 @@ class InstanceIdTarget(
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
-        self, target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup
+        self,
+        target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
         """Register this instance target with a load balancer.
 
@@ -75,7 +78,8 @@ class InstanceIdTarget(
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
-        self, target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup
+        self,
+        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
         """Register this instance target with a load balancer.
 
@@ -137,9 +141,9 @@ class IpTarget(
 
     def __init__(
         self,
-        ip_address: str,
+        ip_address: builtins.str,
         port: typing.Optional[jsii.Number] = None,
-        availability_zone: typing.Optional[str] = None,
+        availability_zone: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new IPAddress target.
 
@@ -169,7 +173,8 @@ class IpTarget(
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
-        self, target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup
+        self,
+        target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
         """Register this instance target with a load balancer.
 
@@ -185,7 +190,8 @@ class IpTarget(
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
-        self, target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup
+        self,
+        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
         """Register this instance target with a load balancer.
 
@@ -222,7 +228,8 @@ class LambdaTarget(
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
-        self, target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup
+        self,
+        target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
         """Register this instance target with a load balancer.
 
@@ -238,7 +245,8 @@ class LambdaTarget(
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
-        self, target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup
+        self,
+        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
         """Register this instance target with a load balancer.
 
